from .MrJattParser import MrJattParser
from .YoutubeParser import YoutubeParser
class MusicWebsiteFactory:

	def getParser(self,parser_name):
		#print "fuck yeh"
		#print parser_name
		parser_name.lower()
		if parser_name.lower()=="mr jatt":
			return MrJattParser()
		elif parser_name.lower()=="youtube":	
			return YoutubeParser()
		else:
			raise NotImplementedError('parser for this music website not implemented')	


# skele/commands/download.py
"""The hello command."""
 
 
from json import dumps
 
from .base import Base
from .FactoryProducer import FactoryProducer
from .FileDownload import FileDownload
class Download(Base):
 
    def run(self):
        name=self.options["TEXT"]
        download_all_flag = self.options["--download-all"]
        if self.options['-y'] == True:   
            self.download_from_youtube(name)
        elif self.options['-d'] == True:
            self.download_from_mr_jatt(name,download_all_flag)


    def download_from_youtube(self,name):
        factory = FactoryProducer()
        p = factory.getFactory("search engine parser factory")
        print "Download from youtube" 
        q = factory.getFactory("music website parser factory")
        q = q.getParser("youtube")
        link = q.Parse(name)
        file_download=FileDownload()
        file_download.file_download_using_youtube_dl(link)    


    def download_from_mr_jatt(self,name,flag):
        factory = FactoryProducer()
        p = factory.getFactory("search engine parser factory")
        p=p.getParser("google")
        website_url = p.Parse(name,"mr jatt")
        q = factory.getFactory("music website parser factory")
        q = q.getParser("mr jatt")
        download_url = q.Parse(website_url,name,flag)
        file_download=FileDownload()
        if flag == True:
            print "All songs will be downloaded for %s"%(' '.join(name))
            for url in download_url:
                print url[0],url[1]
                temp = q.Parse(url[0],url[1],False)
                file_download.file_download_cross_platform(temp)
        else:
            file_download.file_download_cross_platform(download_url)
                    






from .MusicWebsiteParser import MusicWebsiteParser
from ..FileDownload import FileDownload
from BeautifulSoup import BeautifulSoup

class YoutubeParser(MusicWebsiteParser):

	def Parse(self,song_name):
		song_name = '+'.join(song_name)
		url="https://www.youtube.com/results?search_query="
		url=url+song_name
		file_download=FileDownload()
		html=file_download.get_html_response(url)
		soup=BeautifulSoup(html)
		download_url = soup.find('a',attrs={'class':'yt-uix-tile-link yt-ui-ellipsis yt-ui-ellipsis-2 yt-uix-sessionlink      spf-link '})
		temp_url='https://www.youtube.com'
		final_url=temp_url+download_url.get('href')
		return final_url

		